package zdialog;

import javafx.scene.Node;
import javafx.scene.Parent;
import javafx.scene.Scene;
import javafx.stage.Stage;
import zdialog.models.DialogModel;

/**
 * A container for dialog content.
 * 
 * @author graham
 * @param <T> the model type for the pane
 */

public abstract class DialogPane<T extends DialogModel<?>> extends Parent
{
	private T model;
	private Node content;

	public DialogPane(T model)
	{
		this.model = model;
	}

	public T getModel()
	{
		return model;
	}

	public Node getContent()
	{
		return content;
	}

	public void setContent(Node node)
	{
		this.content = node;
	}

	public abstract Parent buildContent();
	
	public void show(Stage stage)
	{
		stage.setScene(new Scene(buildContent()));
		stage.setTitle(model.getTitle());
		stage.initModality(model.getModality());
		if (model.isWait())
		{
			stage.showAndWait();
		}
		else
		{
			stage.show();
		}
	}
}
