package zdialog;

import zdialog.models.StandardDialogResult;
import javafx.beans.value.ObservableValue;
import javafx.geometry.Pos;
import javafx.scene.Node;
import javafx.scene.Parent;
import javafx.scene.control.Label;
import javafx.scene.image.Image;
import javafx.scene.image.ImageView;
import javafx.scene.layout.GridPane;
import javafx.scene.layout.HBox;
import javafx.stage.Stage;
import zdialog.resources.Resources;
import zdialog.models.StandardDialogsModel;

/**
 * A standard Ok/Cancel dialog -- could sub-class some standard dialog to make it cleaner.
 *
 * @author graham
 */
public class OkCancelDialog extends DialogPane<StandardDialogsModel>
{

	private Node mastheadNode;
	private Node messageNode;
	private HBox buttonBar;

	public OkCancelDialog(StandardDialogsModel model)
	{
		super(model);
	}

	public OkCancelDialog(String title)
	{
		this(new StandardDialogsModel(title));
	}

	public void setMasthead(String masthead)
	{
		Label label = new Label(masthead);
		Image img = new Image(Resources.class.getResourceAsStream("INFORMATION.png"), 16, 16, true, true);
		label.setGraphic(new ImageView(img));
		mastheadNode = label;
	}

	public void setMessage(String message)
	{
		messageNode = new Label(message);
	}

	public HBox getButtonBar()
	{
		return buttonBar;
	}

	public HBox createButtonBar()
	{
		//	the order of buttons and alignment etc. would be platform specific -- could even have
		//	this in a utility class with a sort order.
		HBox bar = new HBox();
		bar.setAlignment(Pos.CENTER);
		bar.getChildren().add(StandardDialogButtons.createOkButton(getModel()));
		bar.getChildren().add(StandardDialogButtons.createCancelButton(getModel()));
		return bar;
	}

	@Override
	public Parent buildContent()
	{
		GridPane content = new GridPane();
		content.setVgap(5);	//	would of course be styleable
		buttonBar = createButtonBar();
		int row = 0;
		if (mastheadNode != null)
		{
			GridPane.setConstraints(mastheadNode, 0, row++);
			content.getChildren().add(mastheadNode);

		}
		if (messageNode != null)
		{
			GridPane.setConstraints(messageNode, 0, row++);
			content.getChildren().add(messageNode);
		}
		if (buttonBar != null)
		{
			GridPane.setConstraints(buttonBar, 0, row);
			content.getChildren().add(buttonBar);
		}
		setContent(content);

		return content;
	}

	public void showDialog()
	{
		//	could also switch on lightweightness here
		Stage stage = new Stage();
		stage.setWidth(400);
		getModel().resultProperty().addListener((ObservableValue<? extends StandardDialogResult> observable, StandardDialogResult oldValue, StandardDialogResult newValue) ->
		{
			stage.hide();
		});

		super.show(stage);
	}
}
