package zdialog;

import zdialog.models.StandardDialogResult;
import javafx.beans.value.ObservableValue;
import javafx.scene.Node;
import javafx.scene.Parent;
import javafx.scene.control.Label;
import javafx.scene.image.Image;
import javafx.scene.image.ImageView;
import javafx.scene.layout.GridPane;
import javafx.scene.layout.HBox;
import zdialog.models.ReusingModel;
import zdialog.models.StandardDialogsModel;
import zdialog.resources.Resources;

/**
 * A dialog that re-uses Ok/Cancel dialogs -- clicking cancel on all N cancel buttons
 * cancels the dialog.
 *
 * @author graham
 */
public class ReusingDialog extends DialogPane<ReusingModel>
{

	private int cancelled;
	//
	private Node mastheadNode;

	public ReusingDialog(ReusingModel model)
	{
		super(model);
		cancelled = 0;
	}

	public void setMasthead(String masthead)
	{
		Label label = new Label(masthead);
		Image img = new Image(Resources.class.getResourceAsStream("WARNING.png"), 16, 16, true, true);
		label.setGraphic(new ImageView(img));
		mastheadNode = label;
	}

	@Override
	public Parent buildContent()
	{
		GridPane content = new GridPane();
		int row = 0;
		if (mastheadNode != null)
		{
			GridPane.setConstraints(mastheadNode, 0, row++);
			content.getChildren().add(mastheadNode);
		}

		HBox box = new HBox();
		for (StandardDialogsModel model1 : getModel().getModels())
		{
			OkCancelDialog d = new OkCancelDialog(model1);
			d.setMessage("Some new message");
			box.getChildren().add(d.buildContent());
		}
		GridPane.setConstraints(box, 0, row);
		content.getChildren().add(box);

		for (StandardDialogsModel model1 : getModel().getModels())
		{
			model1.resultProperty().addListener((ObservableValue<? extends StandardDialogResult> observable, StandardDialogResult oldValue, StandardDialogResult newValue) ->
			{
				if (newValue == StandardDialogResult.CANCEL)
				{
					cancelled++;
					if (cancelled == getModel().getModels().length)
					{
						getModel().resultProperty().set(StandardDialogResult.CANCEL);
					}
				}
			});
		}
		setContent(content);
		return content;
	}

	public void showDialog()
	{
		DialogStage stage = new DialogStage();
		stage.setWidth(800);

		//	could mix-in a standard hide behavior
		getModel().resultProperty().addListener((ObservableValue<? extends StandardDialogResult> observable, StandardDialogResult oldValue, StandardDialogResult newValue) ->
		{
			stage.hide();
		});

		super.show(stage);
	}
}
