package zdialog;

import javafx.application.Application;
import javafx.beans.value.ObservableValue;
import javafx.event.ActionEvent;
import javafx.scene.Scene;
import javafx.scene.control.Button;
import javafx.scene.layout.HBox;
import javafx.stage.Stage;
import zdialog.models.ReusingModel;
import zdialog.models.StandardDialogResult;

/**
 * A demonstration for an approach to dialogs that uses models and tries to factor dialogs
 * into re-usable pieces.
 * 
 * @author graham
 */
public class ZDialogExperiment extends Application
{

	@Override
	public void start(Stage primaryStage)
	{
		Button okCancelButton = new Button();
		okCancelButton.setText("Ok/Cancel Dialog");
		okCancelButton.setOnAction((ActionEvent event) ->
		{
			OkCancelDialog dialog = new OkCancelDialog("This is an OkCancel Dialog");
			//	fluent API anyone?
			dialog.setMasthead("Some masthead text");
			dialog.setMessage("Do you really want to do that?");
			dialog.showDialog();
			System.out.println("Result = " + dialog.getModel().resultProperty().get());
		});

		Button okCancelExtraButton = new Button();
		okCancelExtraButton.setText("Ok/Cancel/Extra Dialog");
		okCancelExtraButton.setOnAction((ActionEvent event) ->
		{
			OkCancelExtraDialog dialog = new OkCancelExtraDialog("This is an OkCancel with an Extra Button Dialog");
			//	fluent API anyone?
			dialog.setMasthead("Some masthead text");
			dialog.setMessage("Do you really want to do that?");
			dialog.showDialog();
			System.out.println("Result = " + dialog.getModel().resultProperty().get());
		});
		
		Button reuseButton = new Button();
		reuseButton.setText("Dialog that re-uses other dialogs");
		reuseButton.setOnAction((ActionEvent event) ->
		{
			ReusingModel model = new ReusingModel("This is an Dialog reusing other dialogs and not waiting", 4);
			model.setWait(false);
			ReusingDialog dialog = new ReusingDialog(model);
			dialog.setMasthead("Some masthead text");
			dialog.showDialog();
			System.out.println("Non-Wait Result = " + model.resultProperty().get());
			model.resultProperty().addListener((ObservableValue<? extends StandardDialogResult> observable, StandardDialogResult oldValue, StandardDialogResult newValue) ->
			{
			System.out.println("Actual Result = " + model.resultProperty().get());
			});
		});

		HBox root = new HBox();
		root.getChildren().addAll(okCancelButton, okCancelExtraButton, reuseButton);

		Scene scene = new Scene(root, 600, 250);

		primaryStage.setTitle("Hello World!");
		primaryStage.setScene(scene);
		primaryStage.show();
	}

	/**
	 * @param args the command line arguments
	 */
	public static void main(String[] args)
	{
		launch(args);
	}

}
